@@ -431,7 +431,7 @@ impl Value {
             | Value::I64(_)
             | Value::F32(_)
             | Value::F64(_) => true,
-            Value::String(v) => v.parse::<f64>().is_ok() || v.parse::<u64>().is_ok(),
+            Value::String(v) => v.parse::<f64>().is_ok() || v.parse::<i128>().is_ok(),
             _ => false,
         }
     }
